@@ -1,12 +1,12 @@
-"""Submodule providing wrapper for PyKeen's RotatE model."""
+"""Submodule providing wrapper for PyKEEN's RotatE model."""
 from typing import Union, Type, Dict, Any
 from pykeen.training import TrainingLoop
 from pykeen.models import RotatE
-from embiggen.embedders.pykeen_embedders.entity_relation_embedding_model_pykeen import EntityRelationEmbeddingModelPyKeen
+from embiggen.embedders.pykeen_embedders.entity_relation_embedding_model_pykeen import EntityRelationEmbeddingModelPyKEEN
 from pykeen.triples import CoreTriplesFactory
 
 
-class RotatEPyKeen(EntityRelationEmbeddingModelPyKeen):
+class RotatEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
 
     @classmethod
     def model_name(cls) -> str:
